@@ -1,33 +1,39 @@
 ####################################################################################################################################
 ####################################################################################################################################
 ####
+####   MIT License
+####
 ####   ParaMonte: plain powerful parallel Monte Carlo library.
 ####
 ####   Copyright (C) 2012-present, The Computational Data Science Lab
 ####
 ####   This file is part of the ParaMonte library.
 ####
-####   ParaMonte is free software: you can redistribute it and/or modify it
-####   under the terms of the GNU Lesser General Public License as published
-####   by the Free Software Foundation, version 3 of the License.
+####   Permission is hereby granted, free of charge, to any person obtaining a 
+####   copy of this software and associated documentation files (the "Software"), 
+####   to deal in the Software without restriction, including without limitation 
+####   the rights to use, copy, modify, merge, publish, distribute, sublicense, 
+####   and/or sell copies of the Software, and to permit persons to whom the 
+####   Software is furnished to do so, subject to the following conditions:
 ####
-####   ParaMonte is distributed in the hope that it will be useful,
-####   but WITHOUT ANY WARRANTY; without even the implied warranty of
-####   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-####   GNU Lesser General Public License for more details.
+####   The above copyright notice and this permission notice shall be 
+####   included in all copies or substantial portions of the Software.
 ####
-####   You should have received a copy of the GNU Lesser General Public License
-####   along with the ParaMonte library. If not, see,
-####
-####       https://github.com/cdslaborg/paramonte/blob/master/LICENSE
+####   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, 
+####   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF 
+####   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
+####   IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, 
+####   DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR 
+####   OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE 
+####   OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 ####
 ####   ACKNOWLEDGMENT
 ####
-####   As per the ParaMonte library license agreement terms,
-####   if you use any parts of this library for any purposes,
-####   we ask you to acknowledge the use of the ParaMonte library
-####   in your work (education/research/industry/development/...)
-####   by citing the ParaMonte library as described on this page:
+####   ParaMonte is an honor-ware and its currency is acknowledgment and citations.
+####   As per the ParaMonte library license agreement terms, if you use any parts of 
+####   this library for any purposes, kindly acknowledge the use of ParaMonte in your 
+####   work (education/research/industry/development/...) by citing the ParaMonte 
+####   library as described on this page:
 ####
 ####       https://github.com/cdslaborg/paramonte/blob/master/ACKNOWLEDGMENT.md
 ####
@@ -339,9 +345,11 @@ class RestartFileContents(OutputFileContents):
         else:
             self._reportWrongPlotName("a none-string none-list object.")
 
+        resetTypeIsHard = None
         if isinstance(resetType, str):
             resetTypeIsHard = resetType.lower()=="hard"
         else:
+            resetTypeIsHard = None
             pm.abort( msg   = "The input argument resetType must be a string representing" + newline
                             + "the type of the reset to be performed on the plots." + newline
                             + "A list of possible plots includes: \"hard\", \"soft\"" + newline
@@ -359,45 +367,52 @@ class RestartFileContents(OutputFileContents):
 
         for requestedPlotType in requestedPlotTypeList:
 
+            plotObject = None
             requestedPlotTypeLower = requestedPlotType.lower()
 
-            is3d        = "3"           in requestedPlotTypeLower
+           #is3d        = "3"           in requestedPlotTypeLower
             isLine      = "line"        in requestedPlotTypeLower
             isScatter   = "scatter"     in requestedPlotTypeLower
             isCovMat    = "covmat"      in requestedPlotTypeLower
             isCorMat    = "cormat"      in requestedPlotTypeLower
 
+            if not resetTypeIsHard:
+                plotComponent = getattr(self, "plot")
+                plotObject = getattr(plotComponent, requestedPlotType)
+                plotObject._reset()
+
             ########################################################################################################################
             #### reset line / scatter
             ########################################################################################################################
 
             if isLine or isScatter:
 
-                lineScatterPlot = LineScatterPlot   ( plotType = requestedPlotType
-                                                    , dataFrame = self.df
-                                                    , methodName = self._methodName
-                                                    , reportEnabled = self._reportEnabled
-                                                    , resetPlot = self._resetPlot
-                                                    )
+                if resetTypeIsHard:
+                    plotObject = LineScatterPlot( plotType = requestedPlotType
+                                                , dataFrame = self.df
+                                                , methodName = self._methodName
+                                                , reportEnabled = self._reportEnabled
+                                                , resetPlot = self._resetPlot
+                                                )
 
-                if self._methodName == pm.names.paradram: lineScatterPlot.ycolumns = self.propNameList[0]
-                lineScatterPlot.ccolumns = []
-                lineScatterPlot.colorbar.kws.extend = "neither"
-                lineScatterPlot.colorbar.kws.orientation = "vertical"
-                lineScatterPlot.colorbar.kws.spacing = "uniform"
+                if self._methodName == pm.names.paradram: plotObject.ycolumns = self.propNameList[0]
+                plotObject.ccolumns = []
+                plotObject.colorbar.kws.extend = "neither"
+                plotObject.colorbar.kws.orientation = "vertical"
+                plotObject.colorbar.kws.spacing = "uniform"
 
                 if isLine:
                     if isScatter:
-                        lineScatterPlot.lineCollection.enabled = False
-                        lineScatterPlot.plot.enabled = True
-                        lineScatterPlot.plot.kws.alpha = 0.2
-                        lineScatterPlot.plot.kws.color = "grey"
-                        lineScatterPlot.plot.kws.linewidth = 0.75
+                        plotObject.lineCollection.enabled = False
+                        plotObject.plot.enabled = True
+                        plotObject.plot.kws.alpha = 0.2
+                        plotObject.plot.kws.color = "grey"
+                        plotObject.plot.kws.linewidth = 0.75
                     else:
-                        lineScatterPlot.lineCollection.enabled = True
-                        lineScatterPlot.plot.enabled = False
+                        plotObject.lineCollection.enabled = True
+                        plotObject.plot.enabled = False
 
-                setattr(self.plot, requestedPlotType, lineScatterPlot)
+                setattr(self.plot, requestedPlotType, plotObject)
 
             ########################################################################################################################
             #### reset covmat / cormat
@@ -410,23 +425,25 @@ class RestartFileContents(OutputFileContents):
                     matrix = None
                     if isCovMat: matrix = self.contents.covMat
                     if isCorMat: matrix = self.contents.corMat
-                    ellipsoidPlot = EllipsoidPlot   ( matrix = matrix
+
+                    if resetTypeIsHard:
+                        plotObject = EllipsoidPlot  ( matrix = matrix
                                                     , plotType = requestedPlotType
                                                     , methodName = self._methodName
                                                     , reportEnabled = self._reportEnabled
                                                     , resetPlot = self._resetPlot
                                                     )
 
-                    ellipsoidPlot.rows = ellipsoidPlot.getLogLinSpace()
-                    ellipsoidPlot.center = self.contents.meanVec
-                    ellipsoidPlot.title.enabled = True
+                    plotObject.rows = plotObject.getLogLinSpace()
+                    plotObject.center = self.contents.meanVec
+                    plotObject.title.enabled = True
                     matrixType = "covariance" if isCovMat else "correlation"
-                    ellipsoidPlot.title.label = "Evolution of the " + matrixType + " matrices of the proposal distribution"
+                    plotObject.title.label = "Evolution of the " + matrixType + " matrices of the proposal distribution"
 
-                    ellipsoidPlot.colorbar.kws.extend = "neither"
-                    ellipsoidPlot.colorbar.kws.orientation = "vertical"
-                    ellipsoidPlot.colorbar.kws.spacing = "uniform"
+                    plotObject.colorbar.kws.extend = "neither"
+                    plotObject.colorbar.kws.orientation = "vertical"
+                    plotObject.colorbar.kws.spacing = "uniform"
 
-                    setattr(self.plot, requestedPlotType, ellipsoidPlot)
+                    setattr(self.plot, requestedPlotType, plotObject)
 
-    ################################################################################################################################
\ No newline at end of file
+    ################################################################################################################################
